@@ -4,6 +4,7 @@ from django.db import models
 from django.forms import fields
 from conflux.widgets import JqSplitDateTimeWidget
 
+
 class JqSplitDateTimeField(fields.MultiValueField):
     widget = JqSplitDateTimeWidget
 
@@ -16,10 +17,10 @@ class JqSplitDateTimeField(fields.MultiValueField):
             fields.CharField(max_length=10),
             fields.CharField(max_length=2),
             fields.CharField(max_length=2),
-            fields.ChoiceField(choices=[('AM','AM'),('PM','PM')])
-            )
+            fields.ChoiceField(choices=[("AM", "AM"), ("PM", "PM")]),
+        )
         super(JqSplitDateTimeField, self).__init__(all_fields, *args, **kwargs)
-    
+
     def compress(self, data_list):
         """
         Takes the values from the MultiWidget and passes them as a
@@ -29,8 +30,10 @@ class JqSplitDateTimeField(fields.MultiValueField):
         if data_list:
             if not (data_list[0] and data_list[1] and data_list[2] and data_list[3]):
                 raise forms.ValidationError("Field is missing data.")
-            input_time = strptime("%s:%s %s"%(data_list[1], data_list[2], data_list[3]), "%I:%M %p")
-            datetime_string = "%s %s" % (data_list[0], strftime('%H:%M', input_time))
-            print("Datetime: %s"%datetime_string)
+            input_time = strptime(
+                "%s:%s %s" % (data_list[1], data_list[2], data_list[3]), "%I:%M %p"
+            )
+            datetime_string = "%s %s" % (data_list[0], strftime("%H:%M", input_time))
+            print("Datetime: %s" % datetime_string)
             return datetime_string
         return None
