@@ -11,23 +11,22 @@ from mycms.view_handlers.page_types import allarticles_pagetype_obj
 
 
 class Command(BaseCommand):
-    help = 'Closes the specified poll for voting'
-
+    help = "Closes the specified poll for voting"
 
     def handle(self, *args, **options):
-        
+
         from django.db.models import Q
-        
+
         c = CMSEntries.objects.get(path__path="/sysadmin/linux")
-        
+
         print(c)
-        obj_list = CMSEntries.objects.filter((Q(page_type = singlepageview_pagetype_obj) | 
-                                              Q(page_type = multipageview_pagetype_obj)) &
-                                             Q(path__path__startswith =  c.path.path))        
-        
-        
-        
+        obj_list = CMSEntries.objects.filter(
+            (
+                Q(page_type=singlepageview_pagetype_obj)
+                | Q(page_type=multipageview_pagetype_obj)
+            )
+            & Q(path__path__startswith=c.path.path)
+        )
+
         for obj in obj_list:
             print(obj.path)
-    
-    
\ No newline at end of file
